#include <stdlib.h>
#include <stdio.h>
#include "boards.h"
#include <stdint.h>
#include "app_util_platform.h"
#include "app_error.h"
#include "nrf_drv_twi.h"
#include "LSM9DS1Reg.h"

#include "nrf_log.h"
#include "nrf_log_ctrl.h"
#include "nrf_log_default_backends.h"

/* TWI instance ID. */
#define TWI_INSTANCE_ID     0

 /* Number of possible TWI addresses. */
#define TWI_ADDRESSES	LSM9DS1_AG_ADDRESS

static volatile bool m_xfer_done = false;
static uint8_t m_sample;

/* TWI instance. */
static const nrf_drv_twi_t m_twi = NRF_DRV_TWI_INSTANCE(TWI_INSTANCE_ID);

void twi_init (void)
{
    ret_code_t err_code;

    const nrf_drv_twi_config_t twi_config = {
       .scl                = ARDUINO_SCL_PIN,
       .sda                = ARDUINO_SDA_PIN,
       .frequency          = NRF_TWI_FREQ_100K,
       .interrupt_priority = APP_IRQ_PRIORITY_HIGH,
       .clear_bus_init     = false
    };

    err_code = nrf_drv_twi_init(&m_twi, &twi_config, NULL, NULL);
    APP_ERROR_CHECK(err_code);

    nrf_drv_twi_enable(&m_twi);
}

void lsm9ds1_init(void)
{
	ret_code_t err_code;
	uint8_t reg[2] = {AG_CTRL_REG1_G, AG_ODR_SET};
	err_code = nrf_drv_twi_tx(&m_twi, LSM9DS1_AG_ADDRESS, reg, sizeof(reg), false);
	APP_ERROR_CHECK(err_code);
	
}

static void lsm_read_data()
{
	m_xfer_done = false;
	ret_code_t err_code = nrf_drv_twi_rx(&m_twi, AG_ACC_X_L, &m_sample, sizeof(m_sample));
	APP_ERROR_CHECK(err_code);
}


int main(void)
{
		char test[4];

    APP_ERROR_CHECK(NRF_LOG_INIT(NULL));
    NRF_LOG_DEFAULT_BACKENDS_INIT();
    NRF_LOG_INFO("TWI scanner.");
    NRF_LOG_FLUSH();
	
    twi_init();
		lsm9ds1_init();
		lsm_read_data();

    while (true)
    {
        
    }
}
